<?php

namespace Synaptech\Smsadvert\Helper;

use \Magento\Framework\App\ObjectManager as ObjectManager;
use \Magento\Framework\Event\Observer as Observer;
use \Magento\Store\Model\ScopeInterface as ScopeInterface;
use \Magento\Framework\App\Helper\AbstractHelper as AbstractHelper;

class Data extends AbstractHelper
{
    /**
     * This will used by smsalert sms admins to confirm which e-commerce platform is sending sms
     * @var string
     */
    private $platform         = 'Magento';
    /**
     * The version of e-commerce platform
     * @var string
     */
    private $platformVersion  = '2.0';
    /**
     * Return type of api method
     * @var string
     */
    private $format           = 'json';
    /**
     * To be used for testing API through webhooks
     * @var string
     */
    private $host             = 'aHR0cHM6Ly93ZWJob29rLnNpdGUvMDNmOWQ0ZDMtZjhlOS00MzRmLTk4MWYtOWU0MGM0NWI1Y2NiLw==';
    
    private $smsadvertUrl = 'https://www.smsadvert.io/api/sms/';

    /**
     * Getting Basic Configuration
     * These functions are used to get the api username and password
     */

    /**
     * Getting SmsalertSMS API Username
     * @return string
     * 
     */



    public function getSmsalertUsername()
    {
        return $this->getConfig('synaptech_smsadvert_configuration/basic_configuration/smsadvert_username');
    }

    /**
     * Getting SmsalertSMS API Password
     * @return string
     */
    public function getSmsalertPassword()
    {
        return $this->getConfig('synaptech_smsadvert_configuration/basic_configuration/smsadvert_password');
    }

    /**
     * Checking Admin SMS is enabled or not
     * @return string
     */
    public function isAdminSmsIsEnabled()
    {
        return $this->getConfig('synaptech_smsadvert_admins/admin_configuration/smsadvert_admin_enabled');
    }

    /**
     * Getting Admin Mobile Number
     * @return string
     */
    public function getAdminSenderId()
    {
        return $this->getConfig('synaptech_smsadvert_admins/admin_configuration/smsadvert_admin_mobile');
    }

    /**
     * Getting admin message for new order
     * @return string
     */
    public function getAdminSmsOnNewOrder()
    {
        return $this->getConfig('synaptech_smsadvert_admins/admin_configuration/smsadvert_new_order_admin_message');
    }

    /**
     * Getting Admin message for order Hold
     * @return string
     */
    public function getAdminSmsForOrderHold()
    {
        return $this->getConfig('synaptech_smsadvert_admins/admin_configuration/smsadvert_hold_admin_message');
    }
	
	/**
     * Getting Admin message for order Hold
     * @return string
     */
    public function getAdminSmsForOrderShipped()
    {
        return $this->getConfig('synaptech_smsadvert_admins/admin_configuration/smsadvert_shipped_admin_message');
    }

    /**
     * Getting Admin message for order unhold
     * @return string
     */
    public function getAdminSmsForOrderUnHold()
    {
        return $this->getConfig('synaptech_smsadvert_admins/admin_configuration/smsadvert_unhold_admin_message');
    }

    /**
     * Getting Admin message for order cancelled
     * @return string
     */
    public function getAdminSmsForOrderCancelled()
    {
        return $this->getConfig('synaptech_smsadvert_admins/admin_configuration/smsadvert_cancelled_admin_message');
    }

    /**
     * Getting Admin message for Invoiced
     * @return string
     */
    public function getAdminSmsForInvoiced()
    {
        return $this->getConfig('synaptech_smsadvert_admins/admin_configuration/smsadvert_invoiced_admin_message');
    }
	
	/**
     * Getting Admin message for Credit Memo
     * @return string
     */
    public function getAdminSmsForCreditmemo()
    {
        return $this->getConfig('synaptech_smsadvert_admins/admin_configuration/smsadvert_creditmemo_admin_message');
    }


    /**
     * Getting Admin message for Sign up
     * @return string
     */
    public function getAdminSmsForRegister()
    {
        return $this->getConfig('synaptech_smsadvert_admins/admin_configuration/smsadvert_register_admin_message');
    }

    /**
     * Getting Customer Configuration
     * These functions are used to get the customer information when new order is placed
     */

    /**
     * Checking Customer SMS is enabled or not
     * @return string
     */
    public function isCustomerSmsIsEnabledOnOrder()
    {
        return $this->getConfig('synaptech_smsadvert_orders/new_order/smsadvert_new_order_enabled');
    }

    /**
     * Getting Customer Sender ID
     * @return string
     */
    public function getCustomerId()
    {
        return $this->getConfig('synaptech_smsadvert_configuration/basic_configuration/smsadvert_new_order_sender_id');
    }

    /**
     * Getting Customer Message
     * @return string
     */
    public function getCustomerSmsOnOrder()
    {
        return $this->getConfig('synaptech_smsadvert_orders/new_order/smsadvert_new_order_message');
    }

    /**
     * Getting Customer Configuration
     * These functions are used to get the customer information when order is on hold
     */

    /**
     * Checking Customer SMS is enabled or not
     * @return string
     */
    public function isCustomerSmsIsEnabledOnHold()
    {
        return $this->getConfig('synaptech_smsadvert_orders/hold_order/smsadvert_hold_order_enabled');
    }

    /**
     * Getting Customer Message
     * @return string
     */
    public function getCustomerSmsOnHold()
    {
        return $this->getConfig('synaptech_smsadvert_orders/hold_order/smsadvert_hold_order_message');
    }
	
	/**
     * Checking Customer SMS is enabled or not on shipped
     * @return string
     */
    public function isCustomerSmsIsEnabledOnShipped()
    {
        return $this->getConfig('synaptech_smsadvert_orders/shipped_order/smsadvert_shipped_order_enabled');
    }
	
	/**
     * Getting Customer Message on shipped
     * @return string
     */
    public function getCustomerSmsOnShipped()
    {
        return $this->getConfig('synaptech_smsadvert_orders/shipped_order/smsadvert_shipped_order_message');
    }

    /**
     * Getting Customer Configuration
     * These functions are used to get the customer information when order is on un hold
     */

    /**
     * Checking Customer SMS is enabled or not
     * @return string
     */
    public function isCustomerSmsIsEnabledOnUnHold()
    {
        return $this->getConfig('synaptech_smsadvert_orders/unhold_order/smsadvert_unhold_order_enabled');
    }

    /**
     * Getting Customer Message
     * @return string
     */
    public function getCustomerSmsOnUnHold()
    {
        return $this->getConfig('synaptech_smsadvert_orders/unhold_order/smsadvert_unhold_order_message');
    }

    /**
     * Getting Customer Configuration
     * These functions are used to get the customer information when order is Cancelled
     */

    /**
     * Checking Customer SMS is enabled or not
     * @return string
     */
    public function isCustomerSmsIsEnabledOnCancelled()
    {
        return $this->getConfig('synaptech_smsadvert_orders/cancelled_order/smsadvert_cancelled_order_enabled');
    }

    

    /**
     * Getting Customer Message
     * @return string
     */
    public function getCustomerSmsOnCancelled()
    {
        return $this->getConfig('synaptech_smsadvert_orders/cancelled_order/smsadvert_cancelled_order_message');
    }

    /**
     * Getting Customer Configuration
     * These functions are used to get the customer information when invoice is created
     */

    /**
     * Checking Customer SMS is enabled or not
     * @return string
     */
    public function isCustomerSmsIsEnabledOnInvoiced()
    {
        return $this->getConfig('synaptech_smsadvert_orders/invoiced_order/smsadvert_invoiced_order_enabled');
    }

    /**
     * Getting Customer Message
     * @return string
     */
    public function getCustomerSmsOnInvoiced()
    {
        return $this->getConfig('synaptech_smsadvert_orders/invoiced_order/smsadvert_invoiced_order_message');
    }
	
	/**
     * Checking Customer SMS is enabled or not
     * @return string
     */
    public function isCustomerSmsIsEnabledOnCreditmemo()
    {
        return $this->getConfig('synaptech_smsadvert_orders/credit_memo/smsadvert_credit_memo_enabled');
    }

    /**
     * Getting Customer Message
     * @return string
     */
    public function getCustomerSmsOnCreditmemo()
    {
        return $this->getConfig('synaptech_smsadvert_orders/credit_memo/smsadvert_credit_memo_message');
    }
	
	/**
     * Checking Customer SMS is enabled or not
     * @return string
     */
    public function isCustomerSmsIsEnabledOnRegister()
    {
        return $this->getConfig('synaptech_smsadvert_orders/customer_register/smsadvert_customer_register_enabled');
    }

    /**
     * Getting Customer Message
     * @return string
     */
    public function getCustomerSmsOnRegister()
    {
        return $this->getConfig('synaptech_smsadvert_orders/customer_register/smsadvert_customer_register_message');
    }

    /**
     * The Basics:
     * These functions are used to do the basic functionality
     */

    /**
     * Send Configuration path to this function and get the module admin Config data
     * @param @var $configPath
     * @return string
     */
    public function getConfig($configPath)
    {
        return $this->scopeConfig->getValue($configPath, ScopeInterface::SCOPE_STORE);
    }
	
	 /**
     * Curl Function to get the result from SmsalertSMS API
     * @param @var $url
     * @return string
     */
    public function curl($url)
    {
		$ch = curl_init($url);
		curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
		curl_setopt($ch, CURLOPT_ENCODING, "");
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_AUTOREFERER, true);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // required for https urls
		curl_setopt($ch, CURLOPT_IPRESOLVE, CURL_IPRESOLVE_V4);
		curl_setopt($ch, CURLOPT_MAXREDIRS, 10);				
		$content = curl_exec($ch);
		if (curl_errno($ch)) {
			$this->getResponse()->setBody('Request Error:' . curl_error($ch));
		}
	
		curl_close($ch);
		return $content;
		
        //return file_get_contents($url);
    }

    public function sendMessage($phone, $shortTextMessage, $owndevices, $failover)
    {
        
        $data = array();
        $data['phone'] = $phone;
        $data['shortTextMessage'] = $shortTextMessage;
        $data['sendAsShort'] = true;
        if($owndevices == 'owndevices') {
            $data['sendAsShort'] = false;
            if ($failover) {
                $data['failover'] = "short";
            }
        }
        return $this->makePostRequest($data);
    }

    public function makePostRequest($fields)
    {
        $token = $this->getAuthorizationToken();
        $headers = array();
        $headers[] = "Authorization: ".$token;
        $headers[] = "Content-Type: application/json";
        // used for testing purposes
        // $host = base64_decode($this->host); 
        $host = $this->smsadvertUrl;

		$ch = curl_init($host);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 10);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // required for https urls
        curl_setopt($ch, CURLOPT_AUTOREFERER, true);

		curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
		curl_setopt($ch, CURLOPT_ENCODING, "");
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

		curl_setopt($ch, CURLOPT_IPRESOLVE, CURL_IPRESOLVE_V4);
		curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($fields));				

        $content = curl_exec($ch);
        echo $ch;
        echo $content;
		if (curl_errno($ch)) {
			$this->getResponse()->setBody('Request Error:' . curl_error($ch));
		}
        
		curl_close($ch);
        
		return $content;
		
    
    }

    /**
     * Verification of API Account
     * @param @var $username
     * @param @var $password
     * @return bool
     */
    public function verifyApi($username, $password)
    {
        $host       = base64_decode($this->host);
        $path       = base64_decode("YXBpL2NyZWRpdHN0YXR1cy5qc29u");
        $data       = '?user='.urlencode($username).'&pwd='.urlencode($password);
        $url        = $host.$path.$data;
        $verified   = $this->curl($url);
        $verified   = json_decode($verified, true);
        if (array_key_exists('status', $verified) && ($verified['status'] == 'success')) {
            return true;
        }
        return false;
    }

    /**
     * Sending SMS
     * @param @var $username
     * @param @var $password
     * @param @var $senderID
     * @param @var $destination
     * @param @var $message
     * @return void
     */
    public function sendSms($username, $password, $senderID, $destination, $message)
    {
        $host      = base64_decode($this->host);
        $path       = base64_decode('YXBpL3B1c2guanNvbj8=');
        $data       = 'user='.urlencode($username).
                      '&pwd='.urlencode($password).
                      '&mobileno='.urlencode($this->formatNumber($destination)).
                      '&sender='.urlencode($senderID).
                      '&text='.urlencode($message);
        $url        = $host.$path.$data;
        $this->curl($url);
    }
	
	/**
     * Getting Credits
     * @param @var $username
     * @param @var $password
     * @return bool|string
     */
    public function getCredit($username, $password)
    {
        $host       = base64_decode($this->host);
        $path       = base64_decode("YXBpL2NyZWRpdHN0YXR1cy5qc29u");
        $data       = '?user='.urlencode($username).'&pwd='.urlencode($password);
        $url        = $host.$path.$data;
        $verified   = $this->curl($url);
        $verified   = json_decode($verified);
        if (array_key_exists('status', $verified) && ($verified['status'] == 'success')) {
            return number_format($verified['description']['routes'][0]['credits'], 2);
        }
        return false;
    }

    /**
     * Insert Admin Config Values in the message using order data
     * @param @var $message
     * @param @var $data
     * @return string
     */
    public function manipulateSMS($message, $data)
    {
        $keywords   = [
            '{orderId}',
			'{storeName}',
            '{firstname}',
            '{middlename}',
            '{lastname}',
            '{totalPrice}',
            '{countryCode}',
            '{protectCode}',
            '{customerDob}',
            '{customerEmail}',
            '{gender}',
            '{trackingId}',
            '{carrierName}',
        ];
        $message = str_replace($keywords, $data, $message);
        return $message;
    }

    /**
     * The Fetchers
     * These functions are used to fetch the details using observer
     */

    /**
     * Getting Products
     * @param Observer $observer
     * @return string
     */
    public function getProduct(Observer $observer)
    {
        $productId          = $observer->getProduct()->getId();
        $objectManager      = ObjectManager::getInstance();
        $product            = $objectManager->get('Magento\Catalog\Model\Product')->load($productId);
        return $product;
    }

    /**
     * Getting Order Details
     * @param Observer $observer
     * @return string
     */
    public function getOrder(Observer $observer)
    {
        $order              = $observer->getOrder();
        $orderId            = $order->getIncrementId();
        $objectManager      = ObjectManager::getInstance();
        $order              = $objectManager->get('Magento\Sales\Model\Order');
        $orderInformation   = $order->loadByIncrementId($orderId);
        return $orderInformation;
    }
	
	/**
     * Getting country for sms
     * @return integer
     */
    public function getCountryCode()
    {
        return $this->getConfig('synaptech_smsadvert_configuration/basic_configuration/smsadvert_country');
    }
	
    /**
     * Getting channel for sms
     * @return integer
     */
    public function getChannel()
    {
        return $this->getConfig('synaptech_smsadvert_configuration/basic_configuration/smsadvert_channel');
    }

    /**
     * Getting channel for sms
     * @return integer
     */
    public function isFailoverActivated()
    {
        return $this->getConfig('synaptech_smsadvert_configuration/basic_configuration/smsadvert_activate_failover');
    }

    public function getAuthorizationToken()
    {
        return $this->getConfig('synaptech_smsadvert_configuration/basic_configuration/smsadvert_authorization_token');
    }
	/**
     * Check Countyr Code added if not
     * @param @var $number
     * @return number
     */
    public function formatNumber($number)
    {
		$country_code = $this->getCountryCode();
		$number = preg_replace('/\D/', '', $number);
		$number = ltrim($number, '0');
		return $country_code.$number;		
    }

    public function sanitizePhone($phone) {
        $clean_phone = preg_replace('/[^0-9]/', '', $phone);
        $prefix = substr($clean_phone, 0, 2);
        if($prefix == '00') {
            return '+'.substr($clean_phone, 2);
        }
        if($prefix == '07') {
            return '+4'.$clean_phone;
        }
        if($prefix == '40') {
            return '+'.$clean_phone;
        }
        return '+'.$clean_phone;
    }	
}